local SOUND_INTERVAL = 52 -- Interval for repeating the sound (1.5 seconds)
local VERTICAL_SPEED = 4 * FRACUNIT -- Speed for faster vertical movement

function A_TDChase(actor)
    -- Ensure the actor has a valid target
    if not actor.target or not actor.target.valid then
        actor.target = nil
        P_SetMobjState(actor, actor.info.seestate) -- Revert to See state
        return
    end

    -- Play the sound every 1.5 seconds
    if not actor.soundtimer or actor.soundtimer <= 0 then
        S_StartSound(actor, sfx_tdsee)
        actor.soundtimer = SOUND_INTERVAL
    else
        actor.soundtimer = actor.soundtimer - 1
    end

    -- Get the target's position
    local target = actor.target
    local dx = target.x - actor.x
    local dy = target.y - actor.y

    -- Calculate angle to target
    actor.angle = R_PointToAngle2(actor.x, actor.y, target.x, target.y)

    -- Move toward the target
    actor.momx = FixedMul(actor.info.speed, cos(actor.angle))
    actor.momy = FixedMul(actor.info.speed, sin(actor.angle))

    -- Vertical movement: Match the player's Z position
    if actor.z < target.z then
        actor.momz = VERTICAL_SPEED -- Move up faster
    elseif actor.z > target.z then
        actor.momz = -VERTICAL_SPEED -- Move down faster
    else
        actor.momz = 0 -- Stay at the same height
    end

    -- Explode if within explosion range
    if P_AproxDistance(dx, dy) < actor.info.painchance then
        P_ExplodeMissile(actor)
        return
    end

    -- Damage the player and explode if too close
    if target.player and P_AproxDistance(dx, dy) < 32 * FRACUNIT then
        P_DamageMobj(target, actor, actor, actor.info.damage, DMG_NORMAL)
        P_ExplodeMissile(actor)
        return
    end
end